/**
 * Copyright (c) 2022, NVIDIA CORPORATION.  All rights reserved.
 *
 * NVIDIA CORPORATION and its licensors retain all intellectual property
 * and proprietary rights in and to this software, related documentation
 * and any modifications thereto.  Any use, reproduction, disclosure or
 * distribution of this software and related documentation without an express
 * license agreement from NVIDIA CORPORATION is strictly prohibited.
 */

const createThemeSwitcher = () => {
    let btn = document.createElement('BUTTON');
    btn.className = 'theme-switcher';
    btn.id = 'theme-switcher';
    btn.onclick = function () {
        const newTheme = themeIsDark() ? 'light' : 'dark';

        sessionStorage.setItem('kit-docs-theme', newTheme);
        document.documentElement.setAttribute('data-theme', newTheme);

        setThemeIcon(this);
        reinitMermaid();
    };
    document.body.appendChild(btn);
    setThemeIcon(btn);
};

const setThemeIcon = (element) => {
    const icon = themeIsDark() ? 'sun' : 'moon';
    element.innerHTML = `<i class='fa fa-${icon}-o'></i>`;
};

const buildMermaidConfig = () => {
    var isDark = themeIsDark();
    var config = {
        startOnLoad: true,
        logLevel: 'error',
        securityLevel: 'loose',
        theme: (isDark ? 'dark' : 'forest'),
        darkMode: (isDark ? 'true' : 'false'),
        background: (isDark ? '#FCFCFC' : '#000000')
    };
    return config;
};

const captureMermaidRaw = () => {
    // store the graph text for each graph
    for (const mermaidDiv of document.getElementsByClassName('mermaid')) {
        mermaidDiv.setAttribute('data-mermaid', mermaidDiv.textContent);
    };
}

const reinitMermaid = () => {
    // reset the graph text for each graph
    for (const mermaidDiv of document.getElementsByClassName('mermaid')) {
        mermaidDiv.textContent = mermaidDiv.getAttribute('data-mermaid');
        mermaidDiv.removeAttribute('data-processed');
    }
    mermaid.initialize(buildMermaidConfig());
    mermaid.contentLoaded();
};

document.addEventListener('DOMContentLoaded', () => {
    captureMermaidRaw();
    createThemeSwitcher();
}, false);
